changeset 21782:f2462c6cb265

(outline-discard-overlays): Interpret PROP as a value for `invisible', not as property name.
author Richard M. Stallman <rms@gnu.org>
date Mon, 27 Apr 1998 01:41:22 +0000
parents 6e9ef4991da8
children 798a28989dde
files lisp/textmodes/outline.el
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/textmodes/outline.el	Mon Apr 27 01:28:39 1998 +0000
+++ b/lisp/textmodes/outline.el	Mon Apr 27 01:41:22 1998 +0000
@@ -433,10 +433,10 @@
 
 
 ;; Exclude from the region BEG ... END all overlays
-;; with a non-nil PROP property.
+;; which have PROP as the value of the `invisible' property.
 ;; Exclude them by shrinking them to exclude BEG ... END,
 ;; or even by splitting them if necessary.
 ;; Overlays without a non-nil PROP property are not touched.
 (defun outline-discard-overlays (beg end prop)
   (if (< end beg)
       (setq beg (prog1 end (setq end beg))))
@@ -446,7 +446,7 @@
 	  o1)
       (while overlays
 	(setq o (car overlays))
-	(if (overlay-get o prop)
+	(if (eq (overlay-get o 'invisible) prop)
 	    ;; Either push this overlay outside beg...end
 	    ;; or split it to exclude beg...end
 	    ;; or delete it entirely (if it is contained in beg...end).
@@ -433,10 +433,10 @@
 ;; Exclude them by shrinking them to exclude BEG ... END,
 ;; or even by splitting them if necessary.
-;; Overlays without a non-nil PROP property are not touched.
+;; Overlays without such an `invisible' property are not touched.
 (defun outline-discard-overlays (beg end prop)
   (if (< end beg)